## Analyses for
## "Exploring the interactions between 
## formal distance and participant-related variables 
## in receptive multilingualism"
## (Vanhove & Berthele, submitted 2014)
## contact: jan.vanhove@unifr.ch

# Read in data
responses <- read.csv(file.choose()) # Select 'Schwedisch.csv'
participants <- read.csv(file.choose()) # Select 'participants_163.csv'
stimuli <- read.csv(file.choose()) # Select 'allStimuli.csv'

# Plot dotcharts stimuli (Figure 2)
writtenstimuli <- subset(stimuli, StimulusType=="target" & Modality=="Written")
writtenstimuli <- droplevels(writtenstimuli[order(writtenstimuli$LevenshteinGermanic),])
spokenstimuli <- subset(stimuli, StimulusType=="target" & Modality=="Spoken")
spokenstimuli <- droplevels(spokenstimuli[order(spokenstimuli$LevenshteinGerman),])
spokenstimuli$WrittenForm <- c("paraply","fönster","kärnkraftverk", "larm",
                               "passiv", "blomma","konst","smart",
                               "märkvärdig","fräsch","ingenjör","självständig",
                               "öst", "fotboll", "lång", "bränna",
                               "is", "smink", "växla", "grupp", "först", "fråga",
                               "försvinna", "kägel", "intryck", "hemlig",
                               "ursprung", "nackdel", "choklad", "korruption", "ensam",
                               "tänka", "skärm", "tydlig", "bliva", "egenskap",
                               "potatis", "överraska", "gå", "äta", "skriva",
                               "försöka", "butelj", "elev", "ägg")

svg("LevenshteinDistribution.svg", width=6.5, height=5.5)
par(mfrow=c(1,2),
    las = 1,
    mar = c(5, 4, 2, 2) + 0.1)

with(writtenstimuli,
     dotchart(x = LevenshteinGermanic,
              labels = Swedish,
              xlab="Germanic Levenshtein distance",
              main="Written items",
              cex=.7))
with(spokenstimuli,
     dotchart(x = LevenshteinGerman,
              labels = WrittenForm,
              xlab="German Levenshtein distance",
              main="Spoken items",
              cex=.7))
dev.off()

# Plot ecdfs participants (Figure 3)
svg("ParticipantDistribution.svg", width=6.5, height=3)
par(mfrow=c(1,2),
    las = 1,
    mar = c(4.5, 4, 1, 2)+0.1)
with(participants[!is.na(participants$VocabularyScore) & !is.na(participants$EnglishOverall),],
     {      plot(ecdf(VocabularyScore), pch=20,
                 xlim=c(0, 42),
                 main="",
                 xlab="Vocabulary score",
                 ylab="Cumulative density")
       plot(ecdf(RavenScore), pch=20,
          xlim=c(0, 36),
          main="",
          xlab="Raven score",
          ylab="Cumulative density")})
par(mfrow=c(1,1))
dev.off()

# Code Subject and Correct as factors
responses$Subject <- factor(responses$Subject)
responses$Correct <- factor(responses$Correct, labels=c("no", "yes"))
participants$Subject <- factor(participants$Subject)

# Merge files
data <- merge(responses, participants, by="Subject")
data <- merge(data, stimuli, by="Stimulus")

# Remove responses to 'profile words' (stimuli w/o cognates)
data <- droplevels(subset(data, StimulusType=="target"))

# Remove data from participants with missing predictor data
data <- droplevels(subset(data, !is.na(VocabularyScore) & !is.na(EnglishOverall)))
data$cEnglishOverall <- data$EnglishOverall - mean(data$EnglishOverall)
data$cDigitSpan <- data$DS.Total - mean(data$DS.Total)

# Split up data according to modality
data_written <- droplevels(subset(data, Modality=="Written"))
data_spoken <- droplevels(subset(data, Modality=="Spoken"))

# Load mgcv package
# run 'install.packages("mgcv")' if this doesn't work
library(mgcv)

# Prepare for parallel computing (not strictly necessary, but should speed up the procedure)
# run 'install.packages("parallel")' if this doesn't work
library(parallel)
cl <- detectCores()-1

# GAMMs without and with interaction for written stimuli
written_nointeraction <- bam(Correct ~ cEnglishOverall +
                                       ti(VocabularyScore) + ti(RavenScore) + ti(LevenshteinGermanic) +
                                       s(Subject, bs="re") + s(Stimulus, bs="re"),
                                       data = data_written,
                             family = binomial,
                             cluster = cl)
written_interaction   <- bam(Correct ~ cEnglishOverall +
                                       ti(VocabularyScore) + ti(RavenScore) + ti(LevenshteinGermanic) +
                                       ti(VocabularyScore, LevenshteinGermanic) + ti(RavenScore, LevenshteinGermanic) +
                                       s(Subject, bs="re") + s(Stimulus, bs="re"),
                             data = data_written,
                             family = binomial,
                             cluster = cl)

# Draw Figure 4
svg("WrittenItems.svg", width=6.5, height=7)
par(mfrow=c(2,2),
    las = 1,
    mar = c(4, 4, 2, 0)+0.1,
    oma = c(0,0,2,0),
    mgp = c(2.3, 1, 0))
vis.gam(written_nointeraction, view=c("VocabularyScore","LevenshteinGermanic"),
        cond = list(cEnglishOverall = median(data$cEnglishOverall),
                    Subject="9318", Stimulus="försiktig"),
        plot.type = "contour", color = "bw", levels=seq(-50, 50, 0.5), labcex = 0.8,
        main = "Without interaction",
        xlab = "Vocabulary score", ylab = "Germanic Levenshtein distance")
vis.gam(written_interaction, view=c("VocabularyScore","LevenshteinGermanic"),
        cond = list(cEnglishOverall = median(data$cEnglishOverall),
                    Subject="9318", Stimulus="försiktig"),
        plot.type = "contour", color = "bw", levels=seq(-50, 50, 0.5), labcex = 0.8,
        main = "With interaction",
        xlab = "Vocabulary score", ylab = "Germanic Levenshtein distance")

vis.gam(written_nointeraction, view=c("RavenScore","LevenshteinGermanic"),
        cond = list(cEnglishOverall = median(data$cEnglishOverall),
                    Subject="9318", Stimulus="försiktig"),
        plot.type = "contour", color = "bw", levels=seq(-50, 50, 0.5), labcex = 0.8,
        main = "",
        xlab = "Raven score", ylab = "Germanic Levenshtein distance")
vis.gam(written_interaction, view=c("RavenScore","LevenshteinGermanic"),
        cond = list(cEnglishOverall = median(data$cEnglishOverall),
                    Subject="9318", Stimulus="försiktig"),
        plot.type = "contour", color = "bw", levels=seq(-50, 50, 0.5), labcex = 0.8,
        main = "",
        xlab = "Raven score", ylab = "Germanic Levenshtein distance")
title("Written items", outer=TRUE)
par(mfrow=c(1,1))
dev.off()

# GAMMs without and with interaction for spoken stimuli
spoken_nointeraction    <- bam(Correct ~ cEnglishOverall +
                                         ti(VocabularyScore) + ti(RavenScore) + ti(LevenshteinGerman) +
                                         s(Subject, bs="re") + s(Stimulus, bs="re"),
                               data = data_spoken,
                               family = binomial, cluster=cl)
spoken_interaction      <- bam(Correct ~ cEnglishOverall +
                               ti(VocabularyScore) + ti(RavenScore) + ti(LevenshteinGerman) +
                               ti(VocabularyScore, LevenshteinGerman) + ti(RavenScore, LevenshteinGerman) +
                               s(Subject, bs="re") + s(Stimulus, bs="re"),
                             data = data_spoken,
                             family = binomial, cluster=cl)

# Draw Figure 5
svg("SpokenItems.svg", width=6.5, height=7)
par(mfrow=c(2,2),
    las = 1,
    mar = c(4, 4, 2, 0)+0.1,
    oma = c(0,0,2,0),
    mgp = c(2.3, 1, 0))
vis.gam(spoken_nointeraction, view=c("VocabularyScore","LevenshteinGerman"),
        cond = list(cEnglishOverall = median(data$cEnglishOverall),
                    Subject="9318", Stimulus="grupp"),
        plot.type = "contour", color = "bw", levels=seq(-50, 50, 0.5), labcex = 0.8,
        main = "Without interaction",
        xlab = "Vocabulary score", ylab = "German Levenshtein distance")
vis.gam(spoken_interaction, view=c("VocabularyScore","LevenshteinGerman"),
        cond = list(cEnglishOverall = median(data$cEnglishOverall),
                    Subject="9318", Stimulus="grupp"),
        plot.type = "contour", color = "bw", levels=seq(-50, 50, 0.5), labcex = 0.8,
        main = "With interaction",
        xlab = "Vocabulary score", ylab = "German Levenshtein distance")

vis.gam(spoken_nointeraction, view=c("RavenScore","LevenshteinGerman"),
        cond = list(cEnglishOverall = median(data$cEnglishOverall),
                    Subject="9318", Stimulus="grupp"),
        plot.type = "contour", color = "bw", levels=seq(-50, 50, 0.5), labcex = 0.8,
        main = "",
        xlab = "Raven score", ylab = "German Levenshtein distance")
vis.gam(spoken_interaction, view=c("RavenScore","LevenshteinGerman"),
        cond = list(cEnglishOverall = median(data$cEnglishOverall),
                    Subject="9318", Stimulus="grupp"),
        plot.type = "contour", color = "bw", levels=seq(-50, 50, 0.5), labcex = 0.8,
        main = "",
        xlab = "Raven score", ylab = "German Levenshtein distance")
title("Spoken items", outer=TRUE)
par(mfrow=c(1,1))
dev.off()
